WheelSlot

Struct WheelSlot 

pub struct WheelSlot {
    pub name: Option<Name>,
    pub optic: WheelSlotOptic,
    pub media_name: Option<String>,
    pub facets: Vec<PrismFacet>,
    pub animation_system: Option<AnimationSystem>,
}
Represents a slot on a Wheel.

The link between a lot and a ChannelSet is done via the wheel slot index. The wheel slot index of a slot is derived from the order of a wheel’s slots. The wheel slot index is normalized to 1.

Corresponds to a <Slot> XML node.

Fields

name: Option<Name>

The unique name of the wheel slot.

Corresponds to the Name XML attribute.

optic: WheelSlotOptic

Optics of the slot, either a color or a filter.

Corresponds to the Color or Filter XML attribute.

media_name: Option<String>

An optional PNG file name without extension containing an image for specific gobos etc.

  • Maximum resolution of picture: 1024x1024
  • Recommended resolution of gobo: 256x256
  • Recommended resolution of animation wheel: 256x256

These resource files are located in a folder called ./wheels in the GDTF archive.

Read wheel slot media resources with ResourceMap::read_wheel_media.

Note 1: More information on the definitions of images used in wheel slots to visualize gobos, animation wheels or color wheels can be found in Annex E of the GDTF specification.

Corresponds to the MediaFileName XML attribute.

facets: Vec<PrismFacet>

If the wheel slot has a prism, a list of prism facets. Otherwise empty.

Corresponds to all <Facet> XML child nodes.

animation_system: Option<AnimationSystem>

If the wheel slot has an animation wheel, defines the optics of the animation.

Corresponds to the <AnimationSystem> XML child node.

Implementations

Source

impl WheelSlot

pub fn filter<'s>( &self, parent_fixture_type: &'s FixtureType, ) -> Option<&'s Filter>

Looks up the optional Filter linked by this wheel slot.

pub fn validate( &self, parent_fixture_type: &FixtureType, resource_map: &mut ResourceMap, result: &mut ValidationResult, )

Performs validation checks on the object.