The General Device Type Format (GDTF) is an open standard for describing devices of the entertainment industry. The latest version, 1.2, is standardised as DIN SPEC 15800:2022.
This crate provides tools to read and inspect GDTF files. This is made up of three parts:
- An object model which closely matches the structure defined in the GDTF specification.
- A fairly lax parser capable of parsing mostly well-formed GDTF files into the object model.
- A small number of utilities for validating and inspecting the object model.
Importantly, the crate aims to stay close to the GDTF specification. It is not a goal to provide a higher-level interface for fixtures represented by a GDTF file.
Example
use gdtf_rs::GdtfFile;
let file = std::fs::File::open("Generic@RGBW8@test.gdtf").expect("failed to read file");
let gdtf = GdtfFile::new(file).expect("failed to parse gdtf");
println!("GDTF file defines {} fixture types", gdtf.description.fixture_types.len());Modules
- Fixture Type Attributes and associated groupings.
- Describes all DMX modes of a device.
- The starting point of the description of a fixture type.
- Fixture type specific presets.
- Physical descriptions of the individual parts of a device.
- Defines the type and dimensions of models.
- Describes the physical constitution of a device.
- Protocols supported by a device.
- History of a device type.
- Basic attribute types used throughout device descriptions.
- Properties of all physical or virtual wheels of a device.
Structs
- Description of fixtures in a GDTF file.
- A GDTF file, the description and resources it provides.
- A resource contained in a GDTF file.
- Provides resource files contained in a GDTF file.
- An error that was encountered during validation.
- Result of performing validation checks on a GDTF file.
Enums
- Format to use when reading a thumbnail resource.
- Error type for operations with GdtfFiles.
- View direction used when reading a 2D model symbol.
- Level of detail used when reading a 3D model mesh.
- Format used when reading a 3D model mesh.
- Details on the type of error that occurred.
- Kinds of objects that can raise validation errors.
Type Aliases
- Generic result type with GdtfError as its error variant